"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.prettierExtensionAll = exports.prettierExtensionCi = void 0;

var _path = require("path");

var _exec = _interopRequireDefault(require("../../cmd/exec"));

var _existFiles = _interopRequireDefault(require("../../cmd/existFiles"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const configs = ['.prettierrc', '.prettierrc.json', '.prettierrc.yml', '.prettierrc.yaml', '.prettierrc.toml', '.prettierrc.js', 'prettier.config.js'];
const prettierExtensionCi = 'json,md,scss,yml,yaml,html';
exports.prettierExtensionCi = prettierExtensionCi;
const prettierExtensionAll = `ts,tsx,js,jsx,${prettierExtensionCi}`;
exports.prettierExtensionAll = prettierExtensionAll;

const prettier = async ({
  cwd,
  cfg,
  log
}, {
  write,
  files,
  extension = prettierExtensionAll
}) => {
  const configFiles = await (0, _existFiles.default)(configs, cwd);
  configFiles.push((0, _path.join)(cfg, 'prettierrc.json'));
  const cmd = './node_modules/.bin/prettier';
  const args = [];
  args.push('--config', configFiles[0]);

  if (write) {
    args.push('--write');
  } else {
    args.push('--list-different');
  }

  if (files) {
    if (files.length === 0) {
      log.info('No files found for prettier');
      return;
    }

    args.push(...files);
  } else {
    args.push(`"./**/*.{${extension}}"`);
  }

  log.info('Run prettier');
  await (0, _exec.default)({
    cmd,
    args,
    cwd,
    log
  });
};

var _default = prettier;
exports.default = _default;