"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createBuilder = exports.createHandler = exports.errorHandler = void 0;

var _chalk = require("chalk");

var _access = _interopRequireDefault(require("../cmd/access"));

var _exit = _interopRequireDefault(require("../cmd/exit"));

var _messageError = _interopRequireDefault(require("../errors/messageError"));

var _tableError = _interopRequireDefault(require("../errors/tableError"));

var _logger = require("./logger");

var _table = _interopRequireDefault(require("./table"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const globalOptions = ['cwd', 'tpl', 'cfg', 'log', 'vvv', 'ci'];

const filterOptions = ([key]) => globalOptions.includes(key);

const filterProps = ([key]) => ![...globalOptions, '_', '$0'].includes(key);

const errorHandler = (msg, error) => {
  if (typeof msg === 'string' && typeof error === 'undefined') {
    (0, _logger.log)(' ');
    (0, _logger.log)(msg);
    (0, _logger.log)(' ');
    (0, _exit.default)();
  }

  if (error instanceof _tableError.default) {
    (0, _logger.log)(' ');
    (0, _logger.log)(`${(0, _chalk.red)('Error')}: ${error.message}`);
    (0, _logger.log)(' ');
    (0, _logger.log)((0, _table.default)(error.list));
    (0, _logger.log)(' ');
    (0, _exit.default)();
  }

  if (error instanceof _messageError.default) {
    (0, _logger.log)('');
    (0, _logger.log)(error.message);
    (0, _logger.log)('');
    (0, _exit.default)();
  }

  if (error instanceof Error) {
    (0, _logger.log)('');
    (0, _logger.log)((0, _chalk.red)(error.message));
    (0, _logger.log)('');
  }

  throw error;
};

exports.errorHandler = errorHandler;

const createHandler = task => async argv => {
  const [isReadableCwd, isReadableCfg, isReadableTpl] = await Promise.all([(0, _access.default)(argv.cwd, 'readable'), (0, _access.default)(argv.cfg, 'readable'), (0, _access.default)(argv.tpl, 'readable')]);

  if (!isReadableCwd) {
    throw new Error(`The folder ${argv.cwd} is not readable`);
  }

  if (!isReadableCfg) {
    throw new Error(`The folder ${argv.cfg} is not readable`);
  }

  if (!isReadableTpl) {
    throw new Error(`The folder ${argv.tpl} is not readable`);
  }

  argv.log.debug(['Paths:', `▸ cwd: ${argv.cwd}`, `▸ cfg: ${argv.cfg}`, `▸ tpl: ${argv.tpl}`, '']);
  const options = Object.fromEntries(Object.entries(argv).filter(filterOptions));
  const props = Object.fromEntries(Object.entries(argv).filter(filterProps));
  await task(options, props);
};

exports.createHandler = createHandler;

const createBuilder = (command, callback) => yargs => callback(yargs).usage(`Usage: $0 ${command} [options]`).help().version(false).showHelpOnFail(false);

exports.createBuilder = createBuilder;