"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.analyseServices = void 0;

var _eslint = _interopRequireDefault(require("../actions/tools/eslint"));

var _prettier = _interopRequireWildcard(require("../actions/tools/prettier"));

var _tsc = _interopRequireDefault(require("../actions/tools/tsc"));

var _spinner = require("../cli/spinner");

var _firstExistFileError = _interopRequireDefault(require("../errors/firstExistFileError"));

var _taskHook = _interopRequireDefault(require("./helpers/taskHook"));

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const analyseServices = ['eslint', 'prettier', 'typescript'];
exports.analyseServices = analyseServices;

const isSelectedService = (value, service) => typeof value === 'undefined' || value === service;

const analyseTask = async (argv, {
  only,
  eslintFiles,
  prettierFiles
}) => {
  await (0, _taskHook.default)(argv, {
    task: 'analyse',
    type: 'pre'
  });

  if (isSelectedService(only, 'prettier')) {
    const prettierOptions = {
      write: !argv.ci,
      extension: argv.ci ? _prettier.prettierExtensionCi : undefined,
      files: prettierFiles
    };
    await (0, _spinner.spinnerAction)((0, _prettier.default)(argv, prettierOptions), 'Analyse: Prettier');
  }

  if (isSelectedService(only, 'eslint')) {
    const eslintOptions = {
      write: !argv.ci,
      files: eslintFiles
    };
    await (0, _spinner.spinnerAction)((0, _eslint.default)(argv, eslintOptions), 'Analyse: ESLint');
  }

  if (isSelectedService(only, 'typescript')) {
    try {
      await (0, _spinner.spinnerAction)((0, _tsc.default)(argv, {
        mode: 'type-check'
      }), 'Analyse: Typescript');
    } catch (error) {
      if (error instanceof _firstExistFileError.default) {
        argv.log.info('Typing check is skipped (tsconfig.json was not found) ');
      } else {
        throw error;
      }
    }
  }

  await (0, _taskHook.default)(argv, {
    task: 'analyse',
    type: 'post'
  });
};

var _default = analyseTask;
exports.default = _default;